@@ -4,7 +4,6 @@
 module Test.All(test) where
 
 import Control.Exception
-import System.Console.CmdArgs
 import Control.Monad
 import Control.Monad.IO.Class
 import Data.Char
@@ -24,18 +23,16 @@ import Refact
 import Hint.All
 import Test.Annotations
 import Test.InputOutput
-import Test.Summary
-import Test.Translate
 import Test.Util
 import System.IO.Extra
 import Language.Haskell.GhclibParserEx.GHC.Utils.Outputable
 
 
 test :: Cmd -> ([String] -> IO ()) -> FilePath -> [FilePath] -> IO Int
-test CmdTest{..} main dataDir files = do
+test CmdMain{..} main dataDir files = do
     rpath <- refactorPath (if cmdWithRefactor == "" then Nothing else Just cmdWithRefactor)
 
-    (failures, (ideas, builtins)) <- withBuffering stdout NoBuffering $ withTests $ do
+    (failures, ideas) <- withBuffering stdout NoBuffering $ withTests $ do
         hasSrc <- liftIO $ doesFileExist "hlint.cabal"
         let useSrc = hasSrc && null files
         testFiles <- if files /= [] then pure files else do
@@ -46,7 +43,7 @@ test CmdTest{..} main dataDir files = do
             pure (file, hints ++ (if takeBaseName file /= "Test" then [] else map (Builtin . fst) builtinHints))
         let wrap msg act = do liftIO $ putStr (msg ++ " "); act; liftIO $ putStrLn ""
 
-        liftIO $ putStrLn "Testing"
+        liftIO $ putStrLn $ "Testing (" ++ (if isRight rpath then "with" else "WITHOUT") ++ " refactoring)"
         liftIO $ checkCommentedYaml $ dataDir </> "default.yaml"
         when useSrc $ wrap "Source annotations" $ do
             config <- liftIO $ readFilesConfig [(".hlint.yaml",Nothing)]
@@ -59,16 +56,9 @@ test CmdTest{..} main dataDir files = do
 
         wrap "Hint names" $ mapM_ (\x -> do progress; testNames $ snd x) testFiles
         wrap "Hint annotations" $ forM_ testFiles $ \(file,h) -> do progress; testAnnotations h file (eitherToMaybe rpath)
-        let hs = [h | (file, h) <- testFiles, takeFileName file /= "Test.hs"]
-        when cmdTypeCheck $ wrap "Hint typechecking" $
-            progress >> testTypeCheck cmdDataDir cmdTempDir hs
-        when cmdQuickCheck $ wrap "Hint QuickChecking" $
-            progress >> testQuickCheck cmdDataDir cmdTempDir hs
 
         when (null files && not hasSrc) $ liftIO $ putStrLn "Warning, couldn't find source code, so non-hint tests skipped"
-        (,) <$> getIdeas <*> getBuiltins
-    whenLoud $ mapM_ print ideas
-    when cmdGenerateSummary $ writeFile "builtin.md" (genBuiltinSummaryMd builtins)
+
     case rpath of
         Left refactorNotFound -> putStrLn $ unlines [refactorNotFound, "Refactoring tests skipped"]
         _ -> pure ()
